package Lorem::Element::TableCell;
{
  $Lorem::Element::TableCell::VERSION = '0.21';
}

use Moose;
use MooseX::SemiAffordanceAccessor;
use MooseX::StrictConstructor;

use Cairo;
use Pango;

extends 'Lorem::Element::Box';




1;
